Module number

Module number 

Functions

parse_str_radix
parse str radix from golang format, but: if 8 or 9 is included in octal literal, it will be treated as decimal literal. This function panics if str is not dec, oct, hex format