parse_str_radix

Function parse_str_radix 

pub fn parse_str_radix(s: &str) -> Result<f64, String>
parse str radix from golang format, but: if 8 or 9 is included in octal literal, it will be treated as decimal literal. This function panics if str is not dec, oct, hex format